==> Spire.Pdf-9.12.0-py3-none-win_amd64.whl: spire/pdf/PdfAnnotationWidgetCollection.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfAnnotationWidgetCollection(PdfAnnotationCollection):
    """
    Represents the loaded annotation collection.
    """

    @dispatch
    def get_Item(self, index: int) -> PdfAnnotation:
        """
        Gets the annotation at the specified index.
        """

        GetDllLibPdf().PdfAnnotationWidgetCollection_get_Item.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfAnnotationWidgetCollection_get_Item.restype = c_void_p
        intPtr = GetDllLibPdf().PdfAnnotationWidgetCollection_get_Item(self.Ptr, index)
        ret = None if intPtr == None else PdfAnnotation(intPtr)
        return ret

    @dispatch
    def get_Item(self, text: str) -> PdfAnnotation:
        """
        Represents the annotation with specified name.
        :param name: The specified annotation name.
        """

        GetDllLibPdf().PdfAnnotationWidgetCollection_get_ItemT.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfAnnotationWidgetCollection_get_ItemT.restype = c_void_p
        intPtr = GetDllLibPdf().PdfAnnotationWidgetCollection_get_ItemT(self.Ptr, text)
        ret = None if intPtr == None else PdfAnnotation(intPtr)
        return ret

    @property
    def PageWidget(self) -> 'PdfPageBase':
        """
        Gets or sets the page.
        """

        GetDllLibPdf().PdfAnnotationWidgetCollection_get_PageWidget.argtypes = [c_void_p]
        GetDllLibPdf().PdfAnnotationWidgetCollection_get_PageWidget.restype = c_void_p
        intPtr = GetDllLibPdf().PdfAnnotationWidgetCollection_get_PageWidget(self.Ptr)
        ret = None if intPtr == None else PdfPageBase(intPtr)
        return ret

    @PageWidget.setter
    def PageWidget(self, value: 'PdfPageBase'):
        GetDllLibPdf().PdfAnnotationWidgetCollection_set_PageWidget.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfAnnotationWidgetCollection_set_PageWidget(self.Ptr, value.Ptr)

    def Add(self, annotation: 'PdfAnnotation') -> int:
        """
        Adds annotation to collection.
        :param annotation: Annotation to be added to collection.
        :returns: Position of the annotation in collection.
        """

        intPtrannotation: c_void_p = annotation.Ptr

        GetDllLibPdf().PdfAnnotationWidgetCollection_Add.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfAnnotationWidgetCollection_Add.restype = c_int
        ret = GetDllLibPdf().PdfAnnotationWidgetCollection_Add(self.Ptr, intPtrannotation)
        return ret

==> Spire.Pdf-10.12.1-py3-none-win_amd64.whl: spire/pdf/PdfAnnotationWidgetCollection.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfAnnotationWidgetCollection(PdfAnnotationCollection):
    """
    Represents the loaded annotation collection.
    """

    @dispatch
    def get_Item(self, index: int) -> PdfAnnotation:
        """
        Gets the annotation at the specified index.
        """

        GetDllLibPdf().PdfAnnotationWidgetCollection_get_Item.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfAnnotationWidgetCollection_get_Item.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfAnnotationWidgetCollection_get_Item,self.Ptr, index)
        ret = None if intPtr == None else PdfAnnotation(intPtr)
        return ret

    @dispatch
    def get_Item(self, text: str) -> PdfAnnotation:
        """
        Represents the annotation with specified name.
        :param name: The specified annotation name.
        """

        GetDllLibPdf().PdfAnnotationWidgetCollection_get_ItemT.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfAnnotationWidgetCollection_get_ItemT.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfAnnotationWidgetCollection_get_ItemT,self.Ptr, text)
        ret = None if intPtr == None else PdfAnnotation(intPtr)
        return ret

    @property
    def PageWidget(self) -> 'PdfPageBase':
        """
        Gets or sets the page.
        """

        GetDllLibPdf().PdfAnnotationWidgetCollection_get_PageWidget.argtypes = [c_void_p]
        GetDllLibPdf().PdfAnnotationWidgetCollection_get_PageWidget.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfAnnotationWidgetCollection_get_PageWidget,self.Ptr)
        ret = None if intPtr == None else PdfPageBase(intPtr)
        return ret

    @PageWidget.setter
    def PageWidget(self, value: 'PdfPageBase'):
        GetDllLibPdf().PdfAnnotationWidgetCollection_set_PageWidget.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfAnnotationWidgetCollection_set_PageWidget,self.Ptr, value.Ptr)

    def Add(self, annotation: 'PdfAnnotation') -> int:
        """
        Adds annotation to collection.
        :param annotation: Annotation to be added to collection.
        :returns: Position of the annotation in collection.
        """

        intPtrannotation: c_void_p = annotation.Ptr

        GetDllLibPdf().PdfAnnotationWidgetCollection_Add.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfAnnotationWidgetCollection_Add.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfAnnotationWidgetCollection_Add,self.Ptr, intPtrannotation)
        return ret
